; docformat = 'rst'
;+
; This is an example program to demontrate how to create a 3D scatter plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "scatter_plot_3d.pro" and run it like this::
;       IDL> .RUN scatter_plot_3d
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Scatter_Plot_3D
 

    ; Create the random data. Set the seed so you see what I see.
    seed = 1L
    x = RandomU(seed, 32)
    y = RandomU(seed, 32)
    z = Exp(-3 * ((x - 0.5)^2 + (y - 0.5)^2))
    
    ; Load a color table and create colors for the scatterplot.
    cgLoadCT, 33
    zcolors = BytScl(z)
    
    ; Set the 3D coordinate space with axes.
    cgSurf, DIST(5), /NODATA, /SAVE, XRANGE=[0,1], $
       YRANGE=[0,1], ZRANGE=[0, 1], XSTYLE=1, $
       YSTYLE=1, ZSTYLE=1, CHARSIZE=2.0, $
       POSITION=[0.1, 0.1, 0.95, 0.95, 0.1, 0.95], $
       XTICKLEN=1, YTICKLEN=1, XGRIDSTYLE=1, YGRIDSTYLE=1
    cgAXIS, XAXIS=1, /T3D, CHARSIZE=2.0
    cgAXIS, YAXIS=1, /T3D, CHARSIZE=2.0
    
    ; Plot the random points in 3D space with a filled circle shape.
    phi = Findgen(32) * (!PI * 2 / 32.)
    phi = [ phi, phi(0) ]
    cgPlotS, x, y, z, PSYM=16, COLOR=zcolors, SYMSIZE=2.5, /T3D
    
    ; Connect the data points to the XY plane of the plot.
    FOR j=0,31 DO cgPlotS, [x(j), x(j)], [y(j), y(j)], [0, z(j)], $
       COLOR=zcolors(j), /T3D
              
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Scatter_Plot_3D
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Scatter_Plot_3D', WTitle='3D Scatter Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'scatter_plot_3d.ps'
  Scatter_Plot_3D
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'scatter_plot_3d.ps', /PNG, Width=600

END